package com.bluefairygames.java.libgdx.gameframework.events;

import java.util.ArrayList;
import java.util.List;

import com.bluefairygames.java.libgdx.gameframework.object.GameObject;
import com.bluefairygames.java.libgdx.gameframework.system.EventManager;

/**
 * Base class for all events.
 * <p>
 * An event is dispatched and routed via the {@link EventManager}. Recipients interested in
 * receiving an event must first register with the {@link EventManager}.
 * 
 * @author Matt Parish
 */
public class Event {

	/**
	 * List of recipients set explicitly by the sender of the event.
	 */
	private List<GameObject> mRecipients;

	private long mDispatchTime;

	public Event() {

		mRecipients = new ArrayList<GameObject>();
	}

	/**
	 * Explicitly designate a particular recipient for this event.
	 * 
	 * @param recipient The desired {@link GameObject} that should handle the event.
	 */
	public void addRecipient(GameObject recipient) {

		mRecipients.add(recipient);
	}

	/**
	 * @return The list of explicitly designated {@link GameObject}s which should handle this event.
	 */
	public List<GameObject> getRecipients() {

		return mRecipients;
	}

	/**
	 * Used to designate a future time to dispatch the event.
	 * 
	 * @param dispatchTime The desired dispatch time.
	 */
	public void setDispatchTime(long dispatchTime) {

		mDispatchTime = dispatchTime;
	}

	public long getDispatchTime() {

		return mDispatchTime;
	}
}
