/**
 * Contains the abstract base class for a component along with any subclasses that extend it.
 */
package com.bluefairygames.java.libgdx.gameframework.object.component;

import com.badlogic.gdx.graphics.Camera;
import com.bluefairygames.java.libgdx.gameframework.object.GameObject;

/**
 * Base class for all components.
 * <p>
 * Subclasses must be sure to implement {@link #update(float) update()} and can override
 * {@link #render(Camera) render()} if there are any visual requirements.
 * 
 * @author Matt Parish
 */
public abstract class Component {

	protected GameObject mParent;

	public Component(GameObject parent) {

		mParent = parent;
	}

	/**
	 * Required method, called once per frame, which should update the necessary elements.
	 * 
	 * @param elapsedTime The time elapsed since the previous update.
	 */
	public abstract void update(float elapsedTime);

	/**
	 * Optional method, called once per frame, which should render any visual elements of this
	 * component.
	 * 
	 * @param camera The camera to which the visual elements should be rendered.
	 */
	public void render(Camera camera) {

	}
}
