package com.bluefairygames.java.libgdx.gameframework.screen;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Screen;
import com.badlogic.gdx.graphics.Color;
import com.badlogic.gdx.graphics.GL10;
import com.badlogic.gdx.graphics.OrthographicCamera;
import com.badlogic.gdx.graphics.g2d.BitmapFont;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.bluefairygames.java.libgdx.gameframework.system.GameplaySystem;
import com.bluefairygames.java.libgdx.gameframework.utils.Constants;

public class GameplayScreen implements Screen {
	private static final String TAG = GameplayScreen.class.getSimpleName();

	protected OrthographicCamera mCamera;
	
	protected BitmapFont mFont;
	protected SpriteBatch mSpriteBatch;
	
	protected GameplaySystem mSystem;
	
	protected int mWidth;
	protected int mHeight;
	
	protected float mElapsedTime;
	protected float mAccumulator;
	protected float mDelta;
	
	public GameplayScreen(int width, int height) {
		
		this(width, height, Constants.DELTA);
	}
	
	public GameplayScreen(int width, int height, float delta) {

		mWidth = width;
		mHeight = height;
		mDelta = Constants.DELTA;
		
		mCamera = new OrthographicCamera();
		mCamera.setToOrtho(false, mWidth, mHeight);
	}
	
	@Override
	public void render(float elapsedTime) {

		mAccumulator += elapsedTime;
		while(mAccumulator >= mDelta) {
			
			mSystem.update(mDelta);
			mAccumulator -= mDelta;
			mElapsedTime += mDelta;
		}
		
		Gdx.gl.glClearColor(0, 0, 0, 1);
		Gdx.gl.glClear(GL10.GL_COLOR_BUFFER_BIT);
		
		mCamera.update();
		
		mSystem.render();
		mSpriteBatch.begin();
		mFont.draw(mSpriteBatch, "FPS: " + Gdx.graphics.getFramesPerSecond(), 20, 20);
		mSpriteBatch.end();
	}

	@Override
	public void resize(int width, int height) {

		mWidth = width;
		mHeight = height;
		
		// TODO possibly need to setOrtho on the camera with the new dimensions
	}

	@Override
	public void show() {

		Gdx.input.setInputProcessor(mSystem.getInput());
		
		mElapsedTime = 0;
		mAccumulator = 0;
		
		mFont = new BitmapFont();
		mFont.setColor(Color.WHITE);
		
		mSpriteBatch = new SpriteBatch();
	}
	
	@Override
	public void hide() {}

	@Override
	public void pause() {}

	@Override
	public void resume() {}

	@Override
	public void dispose() {

		mSystem.finish();
	}
}
