package com.bluefairygames.java.libgdx.gameframework.screen;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Screen;
import com.badlogic.gdx.graphics.GL10;
import com.badlogic.gdx.graphics.OrthographicCamera;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.Texture.TextureFilter;
import com.badlogic.gdx.graphics.g2d.Sprite;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.graphics.g2d.TextureRegion;
import com.bluefairygames.java.libgdx.gameframework.enums.ScreenEnum;
import com.bluefairygames.java.libgdx.gameframework.events.screen.ScreenTransition;
import com.bluefairygames.java.libgdx.gameframework.system.EventManager;
import com.bluefairygames.java.libgdx.gameframework.utils.Constants;

public class SplashScreen implements Screen {
	private static final String TAG = SplashScreen.class.getSimpleName();
		
	private SpriteBatch mSpriteBatch;
	private Sprite mSprite;
	private Texture mTexture;
	
	private OrthographicCamera mCamera;
	
	private float mElapsedTime;
	private float mDuration;

	private ScreenEnum mNextScreen;
	
	public SplashScreen(String fileName, ScreenEnum nextScreen) {
		
		this(fileName, Constants.SPLASH_DURATION, nextScreen);
	}
	
	public SplashScreen(String fileName, float duration, ScreenEnum nextScreen) {
		
		mNextScreen = nextScreen;
		mDuration = duration;
		
		mTexture = new Texture(Gdx.files.internal(fileName));
		mTexture.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		
		TextureRegion region = new TextureRegion(mTexture, 0, 0, mTexture.getWidth(),
				mTexture.getHeight());
		
		mSprite = new Sprite(region);
		mSprite.setSize(0.5f * mSprite.getHeight() / mSprite.getWidth(),
				0.5f * mSprite.getHeight() / mSprite.getWidth());
		mSprite.setOrigin(mSprite.getWidth() / 2, mSprite.getHeight() / 2);
		mSprite.setPosition(-mSprite.getWidth() / 2, -mSprite.getHeight() / 2);
		
		mSpriteBatch = new SpriteBatch();
		
		float width = Gdx.graphics.getWidth();
		float height = Gdx.graphics.getHeight();
		
		mCamera = new OrthographicCamera(1, height/width);
		
		Gdx.app.log(TAG, "Initialized; id: " + mTexture.getTextureObjectHandle() + " dimens: "
			+ mTexture.getWidth() + "x" + mTexture.getHeight());
	}

	@Override
	public void render(float elapsedTime) {
		
		mElapsedTime += elapsedTime;
		if(mElapsedTime >= mDuration) {
			
			EventManager.get().dispatchImmediate(new ScreenTransition(mNextScreen));
		}
		
		Gdx.gl.glClearColor(Constants.CLEAR_COLOR.x, Constants.CLEAR_COLOR.y,
				Constants.CLEAR_COLOR.z, 1);
		Gdx.gl.glClear(GL10.GL_COLOR_BUFFER_BIT);
		
		mSpriteBatch.setProjectionMatrix(mCamera.combined);
		mSpriteBatch.begin();
		mSprite.draw(mSpriteBatch);
		mSpriteBatch.end();
	}

	@Override
	public void show() {}
	
	@Override
	public void hide() {}

	@Override
	public void pause() {}

	@Override
	public void resume() {}

	@Override
	public void resize(int width, int height) {

		// TODO Handle a resize event
		
	}

	@Override
	public void dispose() {

		mTexture.dispose();
		mSpriteBatch.dispose();
	}

}
