package com.bluefairygames.java.libgdx.gameframework.system;

import java.util.HashMap;
import java.util.Map;

import com.badlogic.gdx.InputProcessor;
import com.badlogic.gdx.graphics.OrthographicCamera;
import com.badlogic.gdx.graphics.g2d.BitmapFont;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.bluefairygames.java.libgdx.gameframework.enums.ObjectEnum;
import com.bluefairygames.java.libgdx.gameframework.events.movement.Backward;
import com.bluefairygames.java.libgdx.gameframework.events.movement.Forward;
import com.bluefairygames.java.libgdx.gameframework.events.movement.Left;
import com.bluefairygames.java.libgdx.gameframework.events.movement.Right;
import com.bluefairygames.java.libgdx.gameframework.events.screen.ToggleEvent;
import com.bluefairygames.java.libgdx.gameframework.object.GameObject;
import com.bluefairygames.java.libgdx.gameframework.utils.Constants;

public class GameplaySystem {
	private static final String TAG = GameplaySystem.class.getSimpleName();
	
	protected GameplayInput mInput;

	protected OrthographicCamera mCamera;
	protected SpriteBatch mSpriteBatch;
	protected BitmapFont mFont;
	
	protected boolean mFollowPlayer = false;
	
	public GameplaySystem() {
		
		mInput = new GameplayInput();
		mSpriteBatch = new SpriteBatch();
		mFont = new BitmapFont();
	}
	
	public InputProcessor getInputProcessor() {
		
		return mInput;
	}
	
	public void update(float elapsedTime) {
		
		EventManager.get().update(elapsedTime);
		
		for(GameObject object : Blackboard.get().getAll()) {
			
			object.update(elapsedTime);
		}
	}
	
	public void render() {
		
		if(mFollowPlayer) {
			
			GameObject player = Blackboard.get().getObject(ObjectEnum.PLAYER);
			
			mCamera.position.x = player.getPosition().x;
			mCamera.position.y = player.getPosition().y;
			mCamera.update();
		}
		
		for(GameObject object : Blackboard.get().getAll()) {
			
			object.render(mCamera);
		}
	}
	
	public InputProcessor getInput() {
		
		return mInput;
	}
	
	public void finish() {
		
		mSpriteBatch.dispose();
	}
	
	class GameplayInput implements InputProcessor {

		private Map<Integer, ToggleEvent> mKeyStates;
		
		private GameplayInput() {

			mKeyStates = new HashMap<Integer, ToggleEvent>();
			mKeyStates.put(Constants.KEY_FORWARD, new Forward());
			mKeyStates.put(Constants.KEY_BACKWARD, new Backward());
			mKeyStates.put(Constants.KEY_LEFT, new Left());
			mKeyStates.put(Constants.KEY_RIGHT, new Right());			
		}
		
		@Override
		public boolean keyDown(int key) {

			ToggleEvent event = mKeyStates.get(key);
			if(event != null) {
				
				event.setState(true);
				EventManager.get().dispatch(event);
				return true;
			}
			
			return false;
		}

		@Override
		public boolean keyTyped(char key) {

			return false;
		}

		@Override
		public boolean keyUp(int key) {

			ToggleEvent event = mKeyStates.get(key);
			if(event != null) {
				
				event.setState(false);
				EventManager.get().dispatch(event);
				return true;
			}
			
			return false;
		}

		@Override
		public boolean mouseMoved(int screenX, int screenY) {

			return false;
		}

		@Override
		public boolean scrolled(int amount) {

			return false;
		}

		@Override
		public boolean touchDown(int screenX, int screenY, int pointer, int button) {

			return false;
		}

		@Override
		public boolean touchDragged(int screenX, int screenY, int pointer) {

			return false;
		}

		@Override
		public boolean touchUp(int screenX, int screenY, int pointer, int button) {

			return false;
		}
		
	}
}
